@@ -1,7 +1,7 @@
 package App::PDRUtils::SingleCmd::inc_prereq_version_by;
 
-our $DATE = '2016-12-28'; # DATE
-our $VERSION = '0.09'; # VERSION
+our $DATE = '2017-07-03'; # DATE
+our $VERSION = '0.10'; # VERSION
 
 use 5.010001;
 use strict;
@@ -28,12 +28,16 @@ App::PDRUtils::SingleCmd::inc_prereq_version_by - Increase prereq version by a c
 
 =head1 VERSION
 
-This document describes version 0.09 of App::PDRUtils::SingleCmd::inc_prereq_version_by (from Perl distribution App-PDRUtils), released on 2016-12-28.
+This document describes version 0.10 of App::PDRUtils::SingleCmd::inc_prereq_version_by (from Perl distribution App-PDRUtils), released on 2017-07-03.
 
 =head1 FUNCTIONS
 
 
-=head2 handle_cmd(%args) -> [status, msg, result, meta]
+=head2 handle_cmd
+
+Usage:
+
+ handle_cmd(%args) -> [status, msg, result, meta]
 
 Increase prereq version by a certain increment.
 
@@ -95,7 +99,7 @@ perlancar <perlancar@cpan.org>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2016 by perlancar@cpan.org.
+This software is copyright (c) 2017, 2016 by perlancar@cpan.org.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
